@@ -23,7 +23,7 @@ You will need B<make>.
 
 =head2 Setup
 
-Create a directory and copy the example F<Makefile> and F<project.json>
+Create a directory and copy the example F<Makefile> and F<package.json>
 files from this distribution into it. Then run C<< make install >> to
 install additional Nodejs and Perl dependencies.
 
@@ -234,6 +234,28 @@ Example: L<https://github.com/exportertiny/exportertiny.github.io>
 
 Generated this site: L<https://exportertiny.github.io>
 
+=head2 More Examples
+
+=over
+
+=item *
+
+L<https://typetiny.toby.ink/>
+
+=item *
+
+L<https://story-interact.xlc.pl/>
+
+=item *
+
+L<https://ology.github.io/midi-drummer-tiny-tutorial/>
+
+=item *
+
+L<https://ology.github.io/music-duration-partition-tutorial/>
+
+=back
+
 =head1 BUGS
 
 Please report any bugs to
@@ -261,7 +283,7 @@ MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 use Moo;
 use Web::PerlDistSite::Common -lexical, -all;
 
-our $VERSION = '0.001009';
+our $VERSION = '0.001010';
 
 use Web::PerlDistSite::MenuItem ();
 use HTML::HTML5::Parser ();
